Shared data types for the Astrid secure agent runtime.
This crate provides the canonical definitions for:
- IPC payload schemas (cross-boundary messaging between WASM guests and host)
- LLM message, tool, and streaming types
- Kernel management API request/response types
It has minimal dependencies (serde, uuid) and is WASM-compatible, making it suitable for use in both the kernel runtime and user-space capsule SDKs.
Re-exports
pub use ipc::IpcMessage;pub use ipc::IpcPayload;pub use ipc::OnboardingField;pub use ipc::OnboardingFieldType;pub use ipc::SelectionOption;pub use kernel::CapsuleMetadataEntry;pub use kernel::CommandInfo;pub use kernel::DaemonStatus;pub use kernel::KernelRequest;pub use kernel::KernelResponse;pub use kernel::SYSTEM_SESSION_UUID;pub use llm::ContentPart;pub use llm::LlmResponse;pub use llm::LlmToolDefinition;pub use llm::Message;pub use llm::MessageContent;pub use llm::MessageRole;pub use llm::StopReason;pub use llm::StreamEvent;pub use llm::ToolCall;pub use llm::ToolCallResult;pub use llm::Usage;